@@ -2,6 +2,7 @@
 #' @param name Name of Palette. Run \code{names(PrettyColsPalettes)} to view options.
 #' @param direction Sets order of colors. Default palette is 1. If direction is -1,
 #' palette color order is reversed
+#' @param legend_title Character string specifying legend title. Default `NULL`.
 #' @param ... Other arguments passed on to \code{\link[ggplot2]{discrete_scale}}
 #' @return A ggproto object defining a discrete colour scale for use with ggplot2.
 #' @examples
@@ -11,7 +12,9 @@
 #'   scale_color_pretty_d("Relax")
 #' @export
 
-scale_color_pretty_d <- function(name, direction = 1, ...) {
+scale_color_pretty_d <- function(name,
+                                 direction = 1,
+                                 legend_title = NULL, ...) {
   prettycols_disc <- function(name, direction = 1) {
 
     `%notin%` <- Negate(`%in%`)
@@ -34,7 +37,14 @@ scale_color_pretty_d <- function(name, direction = 1, ...) {
 
   }
 
-  ggplot2::discrete_scale(aesthetics = "colour",
-                          scale_name = "pretty_d",
-                          palette = prettycols_disc(name = name, direction = direction), ...)
+  if (!is.null(legend_title)) {
+    ggplot2::discrete_scale(name = legend_title,
+                            aesthetics = "colour",
+                            scale_name = "pretty_d",
+                            palette = prettycols_disc(name = name, direction = direction), ...)
+  } else {
+    ggplot2::discrete_scale(aesthetics = "colour",
+                            scale_name = "pretty_d",
+                            palette = prettycols_disc(name = name, direction = direction), ...)
+  }
 }
